metricgraph documentation
=========================


.. autoclass:: metricgraph.MetricGraph
   :members:
   :undoc-members:
   :show-inheritance:

.. autoclass:: metricgraph.WeightedGraph
   :members:
   :undoc-members:
   :show-inheritance:
